@@ -23,7 +23,7 @@ hwid = ["software"]  # uses its own implementation
 # import usb.core
 
 
-class StellarNet:  # Instantiated as SN
+class instrument:  # Instantiated as SN
     # =============================================================================
     #
     #         '''
@@ -139,7 +139,7 @@ class StellarNet:  # Instantiated as SN
 
 
 if __name__ == "__main__":
-    StellarNet = StellarNet()
+    StellarNet = instrument()
 
     # %%  test bed
     StellarNet.Live()
